//[mahjong-utils](../../index.md)/[mahjongutils.yaku](index.md)

# Package-level declarations

## Types

| Name | Summary |
|---|---|
| [Yaku](-yaku/index.md) | [common]<br>@Serializable(with = YakuSerializer::class)<br>class [Yaku](-yaku/index.md) : YakuChecker<br>役种 |
| [Yakus](-yakus/index.md) | [common]<br>object [Yakus](-yakus/index.md)<br>包含所有役种 |
